@@ -1,9 +1,7 @@
-# encoding: utf-8
-
 """
-binary butterfly validator
-Copyright (c) 2021, binary butterfly GmbH
-Use of this source code is governed by an MIT-style license that can be found in the LICENSE.txt.
+validataclass
+Copyright (c) 2021, binary butterfly GmbH and contributors
+Use of this source code is governed by an MIT-style license that can be found in the LICENSE file.
 """
 
 from decimal import Decimal
@@ -104,7 +102,10 @@ class ValidataclassMixinTest:
         """ Tests the create_with_defaults() class method missing required fields. """
         with pytest.raises(TypeError) as exception_info:
             UnitTestDataclass.create_with_defaults()
-        assert str(exception_info.value) == "__init__() missing 1 required positional argument: 'foo'"
+
+        # The exact exception message changed between Python versions 3.9 (first variant) and 3.10 (second variant)
+        assert str(exception_info.value) == "__init__() missing 1 required positional argument: 'foo'" \
+            or str(exception_info.value) == "UnitTestDataclass.__init__() missing 1 required positional argument: 'foo'"
 
     @staticmethod
     def test_create_with_defaults_on_subclass():
